# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tensorflow/core/profiler/profiler_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from tensorflow.core.framework import graph_pb2 as tensorflow_dot_core_dot_framework_dot_graph__pb2
from tensorflow.core.profiler import op_profile_pb2 as tensorflow_dot_core_dot_profiler_dot_op__profile__pb2
from tensorflow.core.protobuf import config_pb2 as tensorflow_dot_core_dot_protobuf_dot_config__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tensorflow/core/profiler/profiler_service.proto',
  package='tensorflow',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n/tensorflow/core/profiler/profiler_service.proto\x12\ntensorflow\x1a%tensorflow/core/framework/graph.proto\x1a)tensorflow/core/profiler/op_profile.proto\x1a%tensorflow/core/protobuf/config.proto\"-\n\x0eProfileOptions\x12\x1b\n\x13include_dataset_ops\x18\x01 \x01(\x08\"B\n\x12ToolRequestOptions\x12\x16\n\x0eoutput_formats\x18\x02 \x01(\t\x12\x14\n\x0csave_to_repo\x18\x03 \x01(\x08\"\xc9\x02\n\x0eProfileRequest\x12\x13\n\x0b\x64uration_ms\x18\x01 \x01(\x04\x12\x12\n\nmax_events\x18\x02 \x01(\x04\x12\r\n\x05tools\x18\x03 \x03(\t\x12\x41\n\x0ctool_options\x18\x08 \x03(\x0b\x32+.tensorflow.ProfileRequest.ToolOptionsEntry\x12(\n\x04opts\x18\x04 \x01(\x0b\x32\x1a.tensorflow.ProfileOptions\x12\x17\n\x0frepository_root\x18\x05 \x01(\t\x12\x12\n\nsession_id\x18\x06 \x01(\t\x12\x11\n\thost_name\x18\x07 \x01(\t\x1aR\n\x10ToolOptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12-\n\x05value\x18\x02 \x01(\x0b\x32\x1e.tensorflow.ToolRequestOptions:\x02\x38\x01\"-\n\x0fProfileToolData\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\"\x90\x02\n\x0fProfileResponse\x12/\n\x11\x63omputation_graph\x18\x02 \x03(\x0b\x32\x14.tensorflow.GraphDef\x12-\n\x0chlo_metadata\x18\x05 \x01(\x0b\x32\x17.tensorflow.RunMetadata\x12\x15\n\rencoded_trace\x18\x03 \x01(\x0c\x12;\n\nop_profile\x18\x04 \x01(\x0b\x32\'.tensorflow.profiler.op_profile.Profile\x12.\n\ttool_data\x18\x06 \x03(\x0b\x32\x1b.tensorflow.ProfileToolData\x12\x13\n\x0b\x65mpty_trace\x18\x07 \x01(\x08J\x04\x08\x01\x10\x02\"R\n\x0eMonitorRequest\x12\x13\n\x0b\x64uration_ms\x18\x01 \x01(\x04\x12\x18\n\x10monitoring_level\x18\x02 \x01(\x05\x12\x11\n\ttimestamp\x18\x03 \x01(\x08\"\x1f\n\x0fMonitorResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\t2\x9d\x01\n\x0fProfilerService\x12\x44\n\x07Profile\x12\x1a.tensorflow.ProfileRequest\x1a\x1b.tensorflow.ProfileResponse\"\x00\x12\x44\n\x07Monitor\x12\x1a.tensorflow.MonitorRequest\x1a\x1b.tensorflow.MonitorResponse\"\x00\x62\x06proto3')
  ,
  dependencies=[tensorflow_dot_core_dot_framework_dot_graph__pb2.DESCRIPTOR,tensorflow_dot_core_dot_profiler_dot_op__profile__pb2.DESCRIPTOR,tensorflow_dot_core_dot_protobuf_dot_config__pb2.DESCRIPTOR,])




_PROFILEOPTIONS = _descriptor.Descriptor(
  name='ProfileOptions',
  full_name='tensorflow.ProfileOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='include_dataset_ops', full_name='tensorflow.ProfileOptions.include_dataset_ops', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=184,
  serialized_end=229,
)


_TOOLREQUESTOPTIONS = _descriptor.Descriptor(
  name='ToolRequestOptions',
  full_name='tensorflow.ToolRequestOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='output_formats', full_name='tensorflow.ToolRequestOptions.output_formats', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='save_to_repo', full_name='tensorflow.ToolRequestOptions.save_to_repo', index=1,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=231,
  serialized_end=297,
)


_PROFILEREQUEST_TOOLOPTIONSENTRY = _descriptor.Descriptor(
  name='ToolOptionsEntry',
  full_name='tensorflow.ProfileRequest.ToolOptionsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='tensorflow.ProfileRequest.ToolOptionsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='tensorflow.ProfileRequest.ToolOptionsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=547,
  serialized_end=629,
)

_PROFILEREQUEST = _descriptor.Descriptor(
  name='ProfileRequest',
  full_name='tensorflow.ProfileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='duration_ms', full_name='tensorflow.ProfileRequest.duration_ms', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_events', full_name='tensorflow.ProfileRequest.max_events', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tools', full_name='tensorflow.ProfileRequest.tools', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tool_options', full_name='tensorflow.ProfileRequest.tool_options', index=3,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='opts', full_name='tensorflow.ProfileRequest.opts', index=4,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='repository_root', full_name='tensorflow.ProfileRequest.repository_root', index=5,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='session_id', full_name='tensorflow.ProfileRequest.session_id', index=6,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='host_name', full_name='tensorflow.ProfileRequest.host_name', index=7,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_PROFILEREQUEST_TOOLOPTIONSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=300,
  serialized_end=629,
)


_PROFILETOOLDATA = _descriptor.Descriptor(
  name='ProfileToolData',
  full_name='tensorflow.ProfileToolData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='tensorflow.ProfileToolData.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='tensorflow.ProfileToolData.data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=631,
  serialized_end=676,
)


_PROFILERESPONSE = _descriptor.Descriptor(
  name='ProfileResponse',
  full_name='tensorflow.ProfileResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='computation_graph', full_name='tensorflow.ProfileResponse.computation_graph', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hlo_metadata', full_name='tensorflow.ProfileResponse.hlo_metadata', index=1,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='encoded_trace', full_name='tensorflow.ProfileResponse.encoded_trace', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='op_profile', full_name='tensorflow.ProfileResponse.op_profile', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tool_data', full_name='tensorflow.ProfileResponse.tool_data', index=4,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='empty_trace', full_name='tensorflow.ProfileResponse.empty_trace', index=5,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=679,
  serialized_end=951,
)


_MONITORREQUEST = _descriptor.Descriptor(
  name='MonitorRequest',
  full_name='tensorflow.MonitorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='duration_ms', full_name='tensorflow.MonitorRequest.duration_ms', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='monitoring_level', full_name='tensorflow.MonitorRequest.monitoring_level', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='tensorflow.MonitorRequest.timestamp', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=953,
  serialized_end=1035,
)


_MONITORRESPONSE = _descriptor.Descriptor(
  name='MonitorResponse',
  full_name='tensorflow.MonitorResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='tensorflow.MonitorResponse.data', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1037,
  serialized_end=1068,
)

_PROFILEREQUEST_TOOLOPTIONSENTRY.fields_by_name['value'].message_type = _TOOLREQUESTOPTIONS
_PROFILEREQUEST_TOOLOPTIONSENTRY.containing_type = _PROFILEREQUEST
_PROFILEREQUEST.fields_by_name['tool_options'].message_type = _PROFILEREQUEST_TOOLOPTIONSENTRY
_PROFILEREQUEST.fields_by_name['opts'].message_type = _PROFILEOPTIONS
_PROFILERESPONSE.fields_by_name['computation_graph'].message_type = tensorflow_dot_core_dot_framework_dot_graph__pb2._GRAPHDEF
_PROFILERESPONSE.fields_by_name['hlo_metadata'].message_type = tensorflow_dot_core_dot_protobuf_dot_config__pb2._RUNMETADATA
_PROFILERESPONSE.fields_by_name['op_profile'].message_type = tensorflow_dot_core_dot_profiler_dot_op__profile__pb2._PROFILE
_PROFILERESPONSE.fields_by_name['tool_data'].message_type = _PROFILETOOLDATA
DESCRIPTOR.message_types_by_name['ProfileOptions'] = _PROFILEOPTIONS
DESCRIPTOR.message_types_by_name['ToolRequestOptions'] = _TOOLREQUESTOPTIONS
DESCRIPTOR.message_types_by_name['ProfileRequest'] = _PROFILEREQUEST
DESCRIPTOR.message_types_by_name['ProfileToolData'] = _PROFILETOOLDATA
DESCRIPTOR.message_types_by_name['ProfileResponse'] = _PROFILERESPONSE
DESCRIPTOR.message_types_by_name['MonitorRequest'] = _MONITORREQUEST
DESCRIPTOR.message_types_by_name['MonitorResponse'] = _MONITORRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ProfileOptions = _reflection.GeneratedProtocolMessageType('ProfileOptions', (_message.Message,), {
  'DESCRIPTOR' : _PROFILEOPTIONS,
  '__module__' : 'tensorflow.core.profiler.profiler_service_pb2'
  # @@protoc_insertion_point(class_scope:tensorflow.ProfileOptions)
  })
_sym_db.RegisterMessage(ProfileOptions)

ToolRequestOptions = _reflection.GeneratedProtocolMessageType('ToolRequestOptions', (_message.Message,), {
  'DESCRIPTOR' : _TOOLREQUESTOPTIONS,
  '__module__' : 'tensorflow.core.profiler.profiler_service_pb2'
  # @@protoc_insertion_point(class_scope:tensorflow.ToolRequestOptions)
  })
_sym_db.RegisterMessage(ToolRequestOptions)

ProfileRequest = _reflection.GeneratedProtocolMessageType('ProfileRequest', (_message.Message,), {

  'ToolOptionsEntry' : _reflection.GeneratedProtocolMessageType('ToolOptionsEntry', (_message.Message,), {
    'DESCRIPTOR' : _PROFILEREQUEST_TOOLOPTIONSENTRY,
    '__module__' : 'tensorflow.core.profiler.profiler_service_pb2'
    # @@protoc_insertion_point(class_scope:tensorflow.ProfileRequest.ToolOptionsEntry)
    })
  ,
  'DESCRIPTOR' : _PROFILEREQUEST,
  '__module__' : 'tensorflow.core.profiler.profiler_service_pb2'
  # @@protoc_insertion_point(class_scope:tensorflow.ProfileRequest)
  })
_sym_db.RegisterMessage(ProfileRequest)
_sym_db.RegisterMessage(ProfileRequest.ToolOptionsEntry)

ProfileToolData = _reflection.GeneratedProtocolMessageType('ProfileToolData', (_message.Message,), {
  'DESCRIPTOR' : _PROFILETOOLDATA,
  '__module__' : 'tensorflow.core.profiler.profiler_service_pb2'
  # @@protoc_insertion_point(class_scope:tensorflow.ProfileToolData)
  })
_sym_db.RegisterMessage(ProfileToolData)

ProfileResponse = _reflection.GeneratedProtocolMessageType('ProfileResponse', (_message.Message,), {
  'DESCRIPTOR' : _PROFILERESPONSE,
  '__module__' : 'tensorflow.core.profiler.profiler_service_pb2'
  # @@protoc_insertion_point(class_scope:tensorflow.ProfileResponse)
  })
_sym_db.RegisterMessage(ProfileResponse)

MonitorRequest = _reflection.GeneratedProtocolMessageType('MonitorRequest', (_message.Message,), {
  'DESCRIPTOR' : _MONITORREQUEST,
  '__module__' : 'tensorflow.core.profiler.profiler_service_pb2'
  # @@protoc_insertion_point(class_scope:tensorflow.MonitorRequest)
  })
_sym_db.RegisterMessage(MonitorRequest)

MonitorResponse = _reflection.GeneratedProtocolMessageType('MonitorResponse', (_message.Message,), {
  'DESCRIPTOR' : _MONITORRESPONSE,
  '__module__' : 'tensorflow.core.profiler.profiler_service_pb2'
  # @@protoc_insertion_point(class_scope:tensorflow.MonitorResponse)
  })
_sym_db.RegisterMessage(MonitorResponse)


_PROFILEREQUEST_TOOLOPTIONSENTRY._options = None

_PROFILERSERVICE = _descriptor.ServiceDescriptor(
  name='ProfilerService',
  full_name='tensorflow.ProfilerService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=1071,
  serialized_end=1228,
  methods=[
  _descriptor.MethodDescriptor(
    name='Profile',
    full_name='tensorflow.ProfilerService.Profile',
    index=0,
    containing_service=None,
    input_type=_PROFILEREQUEST,
    output_type=_PROFILERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Monitor',
    full_name='tensorflow.ProfilerService.Monitor',
    index=1,
    containing_service=None,
    input_type=_MONITORREQUEST,
    output_type=_MONITORRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_PROFILERSERVICE)

DESCRIPTOR.services_by_name['ProfilerService'] = _PROFILERSERVICE

# @@protoc_insertion_point(module_scope)



# Copyright 2018 The TensorFlow Authors. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ==============================================================================
"""Ops to manipulate lists of tensors."""

# pylint: disable=g-bad-name
from __future__ import absolute_import
from __future__ import division
from __future__ import print_function

from tensorflow.python.framework import dtypes
from tensorflow.python.framework import ops
from tensorflow.python.framework import tensor_shape
from tensorflow.python.ops import array_ops
from tensorflow.python.ops import gen_list_ops
# go/tf-wildcard-import
# pylint: disable=wildcard-import
from tensorflow.python.ops.gen_list_ops import *
# pylint: enable=wildcard-import
from tensorflow.python.util.lazy_loader import LazyLoader

# list_ops -> control_flow_ops -> tensor_array_ops -> list_ops
control_flow_ops = LazyLoader(
    "control_flow_ops", globals(),
    "tensorflow.python.ops.control_flow_ops")


ops.NotDifferentiable("TensorListConcatLists")
ops.NotDifferentiable("TensorListElementShape")
ops.NotDifferentiable("TensorListLength")
ops.NotDifferentiable("TensorListPushBackBatch")


def empty_tensor_list(element_shape,
                      element_dtype,
                      max_num_elements=None,
                      name=None):
  if max_num_elements is None:
    max_num_elements = -1

  return gen_list_ops.empty_tensor_list(
      element_shape=_build_element_shape(element_shape),
      element_dtype=element_dtype,
      max_num_elements=max_num_elements,
      name=name)


def tensor_list_reserve(element_shape, num_elements, element_dtype, name=None):
  return gen_list_ops.tensor_list_reserve(
      element_shape=_build_element_shape(element_shape),
      num_elements=num_elements,
      element_dtype=element_dtype,
      name=name)


def tensor_list_from_tensor(tensor, element_shape, name=None):
  return gen_list_ops.tensor_list_from_tensor(
      tensor=tensor,
      element_shape=_build_element_shape(element_shape),
      name=name)


def tensor_list_get_item(input_handle, index, element_dtype, element_shape=None,
                         name=None):
  return gen_list_ops.tensor_list_get_item(
      input_handle=input_handle,
      index=index,
      element_shape=_build_element_shape(element_shape),
      element_dtype=element_dtype,
      name=name)


def tensor_list_pop_back(input_handle, element_dtype, name=None):
  return gen_list_ops.tensor_list_pop_back(
      input_handle=input_handle,
      element_shape=-1,
      element_dtype=element_dtype,
      name=name)


def tensor_list_gather(input_handle,
                       indices,
                       element_dtype,
                       element_shape=None,
                       name=None):
  return gen_list_ops.tensor_list_gather(
      input_handle=input_handle,
      indices=indices,
      element_shape=_build_element_shape(element_shape),
      element_dtype=element_dtype,
      name=name)


def tensor_list_scatter(tensor,
                        indices,
                        element_shape=None,
                        input_handle=None,
                        name=None):
  if input_handle is not None:
    return gen_list_ops.tensor_list_scatter_into_existing_list(
        input_handle=input_handle, tensor=tensor, indices=indices, name=name)
  else:
    return gen_list_ops.tensor_list_scatter_v2(
        tensor=tensor,
        indices=indices,
        element_shape=_build_element_shape(element_shape),
        num_elements=-1,
        name=name)


def tensor_list_stack(input_handle,
                      element_dtype,
                      num_elements=-1,
                      element_shape=None,
                      name=None):
  return gen_list_ops.tensor_list_stack(
      input_handle=input_handle,
      element_shape=_build_element_shape(element_shape),
      element_dtype=element_dtype,
      num_elements=num_elements,
      name=name)


def tensor_list_concat(input_handle, element_dtype, element_shape=None,
                       name=None):
  # Ignore the lengths output of TensorListConcat. It is only used during
  # gradient computation.
  return gen_list_ops.tensor_list_concat_v2(
      input_handle=input_handle,
      element_dtype=element_dtype,
      element_shape=_build_element_shape(element_shape),
      leading_dims=ops.convert_to_tensor([], dtype=dtypes.int64),
      name=name)[0]


def tensor_list_split(tensor, element_shape, lengths, name=None):
  return gen_list_ops.tensor_list_split(
      tensor=tensor,
      element_shape=_build_element_shape(element_shape),
      lengths=lengths,
      name=name)


def tensor_list_set_item(input_handle,
                         index,
                         item,
                         resize_if_index_out_of_bounds=False,
                         name=None):
  """Sets `item` at `index` in input list."""
  if resize_if_index_out_of_bounds:
    input_list_size = gen_list_ops.tensor_list_length(input_handle)
    # TODO(srbs): This could cause some slowdown. Consider fusing resize
    # functionality in the SetItem op.
    input_handle = control_flow_ops.cond(
        index >= input_list_size,
        lambda: gen_list_ops.tensor_list_resize(  # pylint: disable=g-long-lambda
            input_handle, index + 1),
        lambda: input_handle)
  return gen_list_ops.tensor_list_set_item(
      input_handle=input_handle, index=index, item=item, name=name)


@ops.RegisterGradient("TensorListPushBack")
def _PushBackGrad(op, dresult):
  return gen_list_ops.tensor_list_pop_back(
      dresult,
      element_shape=array_ops.shape(op.inputs[1]),
      element_dtype=op.get_attr("element_dtype"))


@ops.RegisterGradient("TensorListPopBack")
def _PopBackGrad(op, dlist, delement):
  if dlist is None:
    dlist = empty_tensor_list(
        element_dtype=delement.dtype,
        element_shape=gen_list_ops.tensor_list_element_shape(
            op.outputs[0], shape_type=dtypes.int32))
  return gen_list_ops.tensor_list_push_back(dlist, delement), None


@ops.RegisterGradient("TensorListStack")
def _TensorListStackGrad(unused_op, dtensor):
  return tensor_list_from_tensor(dtensor, element_shape=dtensor.shape[1:]), None


@ops.RegisterGradient("TensorListConcat")
@ops.RegisterGradient("TensorListConcatV2")
def _TensorListConcatGrad(op, dtensor, unused_dlengths):
  """Gradient function for TensorListConcat."""
  dlist = tensor_list_split(
      dtensor,
      element_shape=gen_list_ops.tensor_list_element_shape(
          op.inputs[0], shape_type=dtypes.int32),
      lengths=op.outputs[1])
  if op.type == "TensorListConcatV2":
    return dlist, None, None
  else:
    return dlist


@ops.RegisterGradient("TensorListSplit")
def _TensorListSplitGrad(op, dlist):
  tensor, _, lengths = op.inputs
  element_shape = array_ops.slice(array_ops.shape(tensor), [1], [-1])
  element_shape = array_ops.concat([[-1], element_shape], axis=0)
  return gen_list_ops.tensor_list_concat_v2(
      dlist,
      element_shape=element_shape,
      leading_dims=lengths,
      element_dtype=op.inputs[0].dtype)[0], None, None


@ops.RegisterGradient("TensorListFromTensor")
def _TensorListFromTensorGrad(op, dlist):
  """Gradient for TensorListFromTensor."""
  t = op.inputs[0]
  if t.shape.dims and t.shape.dims[0].value is not None:
    num_elements = t.shape.dims[0].value
  else:
    num_elements = None
  if dlist is None:
    dlist = empty_tensor_list(
        element_dtype=t.dtype,
        element_shape=gen_list_ops.tensor_list_element_shape(
            op.outputs[0], shape_type=dtypes.int32))
  tensor_grad = gen_list_ops.tensor_list_stack(
      dlist,
      element_shape=array_ops.slice(array_ops.shape(t), [1], [-1]),
      element_dtype=t.dtype,
      num_elements=num_elements)
  shape_grad = None
  return tensor_grad, shape_grad


@ops.RegisterGradient("TensorListGetItem")
def _TensorListGetItemGrad(op, ditem):
  """Gradient for TensorListGetItem."""
  list_size = gen_list_ops.tensor_list_length(op.inputs[0])
  list_grad = gen_list_ops.tensor_list_set_item(
      gen_list_ops.tensor_list_reserve(
          gen_list_ops.tensor_list_element_shape(op.inputs[0],
                                                 shape_type=dtypes.int32),
          list_size, element_dtype=ditem.dtype),
      index=op.inputs[1],
      item=ditem)
  index_grad = None
  element_shape_grad = None
  return list_grad, index_grad, element_shape_grad


@ops.RegisterGradient("TensorListSetItem")
def _TensorListSetItemGrad(op, dlist):
  """Gradient function for TensorListSetItem."""
  _, index, item = op.inputs
  list_grad = gen_list_ops.tensor_list_set_item(
      dlist, index=index, item=array_ops.zeros_like(item))
  index_grad = None
  element_grad = tensor_list_get_item(
      dlist,
      index,
      element_shape=array_ops.shape(item),
      element_dtype=item.dtype)
  return list_grad, index_grad, element_grad


@ops.RegisterGradient("TensorListResize")
def _TensorListResizeGrad(op, dlist):
  input_list, _ = op.inputs
  input_list_size = gen_list_ops.tensor_list_length(input_list)
  return gen_list_ops.tensor_list_resize(dlist, input_list_size), None


@ops.RegisterGradient("TensorListGather")
def _TensorListGatherGrad(op, dtensor):
  """Gradient function for TensorListGather."""
  input_list, indices, _ = op.inputs
  element_shape = gen_list_ops.tensor_list_element_shape(
      input_list, shape_type=dtypes.int32)
  num_elements = gen_list_ops.tensor_list_length(input_list)
  dlist = tensor_list_reserve(element_shape, num_elements, dtensor.dtype)
  dlist = tensor_list_scatter(
      tensor=dtensor, indices=indices, input_handle=dlist)
  return dlist, None, None


@ops.RegisterGradient("TensorListScatter")
@ops.RegisterGradient("TensorListScatterV2")
def _TensorListScatterGrad(op, dlist):
  """Gradient function for TensorListScatter."""
  tensor = op.inputs[0]
  indices = op.inputs[1]
  dtensor = gen_list_ops.tensor_list_gather(
      dlist,
      indices,
      element_shape=array_ops.slice(array_ops.shape(tensor), [1], [-1]),
      element_dtype=tensor.dtype)
  if op.type == "TensorListScatterV2":
    return dtensor, None, None, None
  else:
    return dtensor, None, None


@ops.RegisterGradient("TensorListScatterIntoExistingList")
def _TensorListScatterIntoExistingListGrad(op, dlist):
  """Gradient function for TensorListScatterIntoExistingList."""
  _, tensor, indices = op.inputs
  dtensor = gen_list_ops.tensor_list_gather(
      dlist,
      indices,
      element_shape=array_ops.slice(array_ops.shape(tensor), [1], [-1]),
      element_dtype=tensor.dtype)
  zeros = array_ops.zeros_like(tensor)
  dlist = tensor_list_scatter(zeros, indices, indices, input_handle=dlist)
  return dlist, dtensor, None


def _build_element_shape(shape):
  """Converts shape to a format understood by list_ops for element_shape.

  If `shape` is already a `Tensor` it is returned as-is. We do not perform a
  type check here.

  If shape is None or a TensorShape with unknown rank, -1 is returned.

  If shape is a scalar, an int32 tensor with empty list is returned. Note we
  do directly return an empty list since ops.convert_to_tensor would conver it
  to a float32 which is not a valid type for element_shape.

  If shape is a sequence of dims, None's in the list are replaced with -1. We
  do not check the dtype of the other dims.

  Args:
    shape: Could be None, Tensor, TensorShape or a list of dims (each dim could
      be a None, scalar or Tensor).

  Returns:
    A None-free shape that can be converted to a tensor.
  """
  if isinstance(shape, ops.Tensor):
    return shape
  if isinstance(shape, tensor_shape.TensorShape):
    # `TensorShape.as_list` requires rank to be known.
    shape = shape.as_list() if shape else None
  # Shape is unknown.
  if shape is None:
    return -1
  # Shape is a scalar.
  if not shape:
    return ops.convert_to_tensor(shape, dtype=dtypes.int32)
  # Shape is a sequence of dimensions. Convert None dims to -1.
  def convert(val):
    if val is None:
      return -1
    if isinstance(val, ops.Tensor):
      return val
    if isinstance(val, tensor_shape.Dimension):
      return val.value if val.value is not None else -1
    return val

  return [convert(d) for d in shape]



# This file is MACHINE GENERATED! Do not edit.
# Generated by: tensorflow/python/tools/api/generator/create_python_api.py script.
"""`tf.data.Dataset` API for input pipelines.

See [Importing Data](https://tensorflow.org/guide/datasets) for an overview.

"""

from __future__ import print_function as _print_function

import sys as _sys

from tensorflow._api.v1.data import experimental
from tensorflow.python.data.ops.dataset_ops import Dataset
from tensorflow.python.data.ops.dataset_ops import DatasetSpec
from tensorflow.python.data.ops.dataset_ops import Options
from tensorflow.python.data.ops.dataset_ops import get_legacy_output_classes as get_output_classes
from tensorflow.python.data.ops.dataset_ops import get_legacy_output_shapes as get_output_shapes
from tensorflow.python.data.ops.dataset_ops import get_legacy_output_types as get_output_types
from tensorflow.python.data.ops.dataset_ops import make_initializable_iterator
from tensorflow.python.data.ops.dataset_ops import make_one_shot_iterator
from tensorflow.python.data.ops.iterator_ops import Iterator
from tensorflow.python.data.ops.readers import FixedLengthRecordDataset
from tensorflow.python.data.ops.readers import TFRecordDataset
from tensorflow.python.data.ops.readers import TextLineDataset

del _print_function

from tensorflow.python.util import module_wrapper as _module_wrapper

if not isinstance(_sys.modules[__name__], _module_wrapper.TFModuleWrapper):
  _sys.modules[__name__] = _module_wrapper.TFModuleWrapper(
      _sys.modules[__name__], "data", public_apis=None, deprecation=True,
      has_lite=False)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tensorflow/compiler/xla/service/hlo.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from tensorflow.compiler.xla import xla_data_pb2 as tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tensorflow/compiler/xla/service/hlo.proto',
  package='xla',
  syntax='proto3',
  serialized_options=_b('\370\001\001'),
  serialized_pb=_b('\n)tensorflow/compiler/xla/service/hlo.proto\x12\x03xla\x1a&tensorflow/compiler/xla/xla_data.proto\"\xdb\x11\n\x13HloInstructionProto\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06opcode\x18\x02 \x01(\t\x12\x1e\n\x05shape\x18\x03 \x01(\x0b\x32\x0f.xla.ShapeProto\x12!\n\x08metadata\x18\x07 \x01(\x0b\x32\x0f.xla.OpMetadata\x12\"\n\x07literal\x18\x08 \x01(\x0b\x32\x11.xla.LiteralProto\x12\x18\n\x10parameter_number\x18\t \x01(\x03\x12\x13\n\x0b\x66usion_kind\x18\x0b \x01(\t\x12\x13\n\x0btuple_index\x18\r \x01(\x03\x12\x12\n\ndimensions\x18\x0e \x03(\x03\x12\x1b\n\x06window\x18\x0f \x01(\x0b\x32\x0b.xla.Window\x12G\n\x1d\x63onvolution_dimension_numbers\x18\x10 \x01(\x0b\x32 .xla.ConvolutionDimensionNumbers\x12\x1b\n\x13\x66\x65\x61ture_group_count\x18\x32 \x01(\x03\x12\x19\n\x11\x62\x61tch_group_count\x18: \x01(\x03\x12\x42\n\x10slice_dimensions\x18\x11 \x03(\x0b\x32(.xla.HloInstructionProto.SliceDimensions\x12\x15\n\rexponent_bits\x18\x12 \x01(\x05\x12\x15\n\rmantissa_bits\x18\x13 \x01(\x05\x12\x1b\n\x13\x64ynamic_slice_sizes\x18\x14 \x03(\x03\x12*\n\x0epadding_config\x18\x15 \x01(\x0b\x32\x12.xla.PaddingConfig\x12\x16\n\x0eoutfeed_config\x18\x16 \x01(\x0c\x12-\n\x0c\x64istribution\x18\x17 \x01(\x0e\x32\x17.xla.RandomDistribution\x12\x0f\n\x07\x65psilon\x18\x18 \x01(\x02\x12\x15\n\rfeature_index\x18\x19 \x01(\x03\x12\x12\n\nchannel_id\x18\x1a \x01(\x03\x12\x15\n\rinfeed_config\x18\x1b \x01(\x0c\x12\x1a\n\x12\x63ustom_call_target\x18\x1c \x01(\t\x12&\n\routfeed_shape\x18\x1d \x01(\x0b\x32\x0f.xla.ShapeProto\x12\x37\n\x15\x64ot_dimension_numbers\x18\x1e \x01(\x0b\x32\x18.xla.DotDimensionNumbers\x12\x1e\n\x08\x66\x66t_type\x18\x1f \x01(\x0e\x32\x0c.xla.FftType\x12\x12\n\nfft_length\x18  \x03(\x03\x12\x1c\n\x14\x63omparison_direction\x18? \x01(\t\x12=\n\x18gather_dimension_numbers\x18! \x01(\x0b\x32\x1b.xla.GatherDimensionNumbers\x12\x1a\n\x12gather_slice_sizes\x18\" \x03(\x03\x12\x14\n\x0c\x63hannel_name\x18) \x01(\t\x12\x18\n\x10\x63ost_estimate_ns\x18* \x01(\x03\x12\n\n\x02id\x18# \x01(\x03\x12\x13\n\x0boperand_ids\x18$ \x03(\x03\x12\x1f\n\x17\x63ontrol_predecessor_ids\x18% \x03(\x03\x12\x1e\n\x16\x63\x61lled_computation_ids\x18& \x03(\x03\x12!\n\x08sharding\x18( \x01(\x0b\x32\x0f.xla.OpSharding\x12\x16\n\x0e\x62\x61\x63kend_config\x18+ \x01(\t\x12)\n\x0ereplica_groups\x18\x31 \x03(\x0b\x32\x11.xla.ReplicaGroup\x12\x19\n\rall_reduce_id\x18- \x01(\x03\x42\x02\x18\x01\x12\x18\n\x10is_host_transfer\x18/ \x01(\x08\x12\x11\n\tis_stable\x18< \x01(\x08\x12?\n\x19scatter_dimension_numbers\x18\x30 \x01(\x0b\x32\x1c.xla.ScatterDimensionNumbers\x12.\n\x10precision_config\x18\x33 \x01(\x0b\x32\x14.xla.PrecisionConfig\x12.\n\x13source_target_pairs\x18\x34 \x03(\x0b\x32\x11.xla.SourceTarget\x12.\n\x15\x64omain_entry_sharding\x18\x36 \x01(\x0b\x32\x0f.xla.OpSharding\x12-\n\x14\x64omain_exit_sharding\x18\x37 \x01(\x0b\x32\x0f.xla.OpSharding\x12\x18\n\x10\x63onstrain_layout\x18\x38 \x01(\x08\x12\x33\n\x1aoperand_shapes_with_layout\x18\x39 \x03(\x0b\x32\x0f.xla.ShapeProto\x12=\n\x18triangular_solve_options\x18; \x01(\x0b\x32\x1b.xla.TriangularSolveOptions\x12.\n\x10\x63holesky_options\x18> \x01(\x0b\x32\x14.xla.CholeskyOptions\x12\x38\n\x15parameter_replication\x18= \x01(\x0b\x32\x19.xla.ParameterReplication\x12\"\n\x1aouter_dimension_partitions\x18@ \x03(\x03\x12#\n\x1b\x63ustom_call_has_side_effect\x18\x41 \x01(\x08\x12\r\n\x05\x64\x65lta\x18\x42 \x01(\x03\x12\x1a\n\x12indices_are_sorted\x18\x43 \x01(\x08\x1a?\n\x0fSliceDimensions\x12\r\n\x05start\x18\x01 \x01(\x03\x12\r\n\x05limit\x18\x02 \x01(\x03\x12\x0e\n\x06stride\x18\x03 \x01(\x03J\x04\x08\n\x10\x0bJ\x04\x08\x0c\x10\rJ\x04\x08\x04\x10\x05J\x04\x08\x05\x10\x06J\x04\x08\x06\x10\x07J\x04\x08,\x10-J\x04\x08\x35\x10\x36J\x04\x08.\x10/R\x0eparameter_nameR\x1e\x66used_instructions_computationR\roperand_namesR\x19\x63ontrol_predecessor_namesR\x18\x63\x61lled_computation_namesR\x11replica_group_idsR\x12\x63ustom_call_opaqueR\x12\x61ll_reduce_barrier\"\xb0\x01\n\x13HloComputationProto\x12\x0c\n\x04name\x18\x01 \x01(\t\x12.\n\x0cinstructions\x18\x02 \x03(\x0b\x32\x18.xla.HloInstructionProto\x12-\n\rprogram_shape\x18\x04 \x01(\x0b\x32\x16.xla.ProgramShapeProto\x12\n\n\x02id\x18\x05 \x01(\x03\x12\x0f\n\x07root_id\x18\x06 \x01(\x03J\x04\x08\x03\x10\x04R\troot_name\"\xd8\x01\n\x10HloScheduleProto\x12\x37\n\tsequences\x18\x01 \x03(\x0b\x32$.xla.HloScheduleProto.SequencesEntry\x1a.\n\x13InstructionSequence\x12\x17\n\x0finstruction_ids\x18\x01 \x03(\x03\x1a[\n\x0eSequencesEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\x38\n\x05value\x18\x02 \x01(\x0b\x32).xla.HloScheduleProto.InstructionSequence:\x02\x38\x01\"\xb4\x02\n\x18HloInputOutputAliasProto\x12>\n\x07\x65ntries\x18\x01 \x03(\x0b\x32-.xla.HloInputOutputAliasProto.AliasEntryProto\x1a\x98\x01\n\x0f\x41liasEntryProto\x12\x1a\n\x12output_shape_index\x18\x01 \x03(\x03\x12\x18\n\x10parameter_number\x18\x02 \x01(\x03\x12\x1d\n\x15parameter_shape_index\x18\x03 \x03(\x03\x12\x30\n\x04kind\x18\x04 \x01(\x0e\x32\".xla.HloInputOutputAliasProto.Kind\"=\n\x04Kind\x12\x13\n\x0fUNDEFINED_ALIAS\x10\x00\x12\x0e\n\nUSER_ALIAS\x10\x01\x12\x10\n\x0cSYSTEM_ALIAS\x10\x02\"\xf2\x01\n\x1c\x44ynamicParameterBindingProto\x12:\n\x07\x65ntries\x18\x01 \x03(\x0b\x32).xla.DynamicParameterBindingProto.Binding\x1a\x95\x01\n\x07\x42inding\x12\x19\n\x11\x64ynamic_param_num\x18\x01 \x01(\x03\x12\x1b\n\x13\x64ynamic_param_index\x18\x02 \x03(\x03\x12\x18\n\x10target_param_num\x18\x03 \x01(\x03\x12\x1a\n\x12target_param_index\x18\x04 \x03(\x03\x12\x1c\n\x14target_param_dim_num\x18\x05 \x01(\x03\"\xf6\x02\n\x0eHloModuleProto\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1e\n\x16\x65ntry_computation_name\x18\x02 \x01(\t\x12\x1c\n\x14\x65ntry_computation_id\x18\x06 \x01(\x03\x12.\n\x0c\x63omputations\x18\x03 \x03(\x0b\x32\x18.xla.HloComputationProto\x12\x32\n\x12host_program_shape\x18\x04 \x01(\x0b\x32\x16.xla.ProgramShapeProto\x12\n\n\x02id\x18\x05 \x01(\x03\x12\'\n\x08schedule\x18\x07 \x01(\x0b\x32\x15.xla.HloScheduleProto\x12\x39\n\x12input_output_alias\x18\x08 \x01(\x0b\x32\x1d.xla.HloInputOutputAliasProto\x12\x44\n\x19\x64ynamic_parameter_binding\x18\t \x01(\x0b\x32!.xla.DynamicParameterBindingProto\"\xc8\x01\n\x12LogicalBufferProto\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0c\n\x04size\x18\x02 \x01(\x03\x12\x34\n\ndefined_at\x18\x03 \x01(\x0b\x32 .xla.LogicalBufferProto.Location\x12\r\n\x05\x63olor\x18\x04 \x01(\x03\x1aS\n\x08Location\x12\x18\n\x10\x63omputation_name\x18\x01 \x01(\t\x12\x18\n\x10instruction_name\x18\x02 \x01(\t\x12\x13\n\x0bshape_index\x18\x03 \x03(\x03\"\xf8\x02\n\x15\x42ufferAllocationProto\x12\r\n\x05index\x18\x01 \x01(\x03\x12\x0c\n\x04size\x18\x02 \x01(\x03\x12\x17\n\x0fis_thread_local\x18\x03 \x01(\x08\x12\x10\n\x08is_tuple\x18\x0b \x01(\x08\x12&\n\x1eis_entry_computation_parameter\x18\x05 \x01(\x08\x12\x13\n\x0bis_constant\x18\x0c \x01(\x08\x12\x18\n\x10parameter_number\x18\x06 \x01(\x03\x12\x1d\n\x15parameter_shape_index\x18\n \x03(\x03\x12\x16\n\x0emaybe_live_out\x18\x07 \x01(\x08\x12\r\n\x05\x63olor\x18\x08 \x01(\x03\x12\x35\n\x08\x61ssigned\x18\t \x03(\x0b\x32#.xla.BufferAllocationProto.Assigned\x1a\x43\n\x08\x41ssigned\x12\x19\n\x11logical_buffer_id\x18\x01 \x01(\x03\x12\x0e\n\x06offset\x18\x02 \x01(\x03\x12\x0c\n\x04size\x18\x03 \x01(\x03\"\xb5\x02\n\x12HeapSimulatorTrace\x12-\n\x06\x65vents\x18\x01 \x03(\x0b\x32\x1d.xla.HeapSimulatorTrace.Event\x12\x1f\n\x17whole_module_simulation\x18\x02 \x01(\x08\x1a\xce\x01\n\x05\x45vent\x12\x30\n\x04kind\x18\x01 \x01(\x0e\x32\".xla.HeapSimulatorTrace.Event.Kind\x12\x11\n\tbuffer_id\x18\x02 \x01(\x03\x12\x18\n\x10\x63omputation_name\x18\x03 \x01(\t\x12\x18\n\x10instruction_name\x18\x04 \x01(\t\x12\x1f\n\x17share_with_canonical_id\x18\x05 \x01(\x03\"+\n\x04Kind\x12\t\n\x05\x41LLOC\x10\x00\x12\x08\n\x04\x46REE\x10\x01\x12\x0e\n\nSHARE_WITH\x10\x02\"M\n\x13HloModuleGroupProto\x12\x0c\n\x04name\x18\x01 \x01(\t\x12(\n\x0bhlo_modules\x18\x02 \x03(\x0b\x32\x13.xla.HloModuleProto\"\xd6\x02\n\x15\x42ufferAssignmentProto\x12\x30\n\x0flogical_buffers\x18\x01 \x03(\x0b\x32\x17.xla.LogicalBufferProto\x12>\n\x0e\x62uffer_aliases\x18\x02 \x03(\x0b\x32&.xla.BufferAssignmentProto.BufferAlias\x12\x36\n\x12\x62uffer_allocations\x18\x03 \x03(\x0b\x32\x1a.xla.BufferAllocationProto\x12\x36\n\x15heap_simulator_traces\x18\x04 \x03(\x0b\x32\x17.xla.HeapSimulatorTrace\x1a[\n\x0b\x42ufferAlias\x12\x18\n\x10source_buffer_id\x18\x01 \x01(\x03\x12\x32\n\x08location\x18\x02 \x01(\x0b\x32 .xla.LogicalBufferProto.Location\"~\n\x08HloProto\x12\'\n\nhlo_module\x18\x01 \x01(\x0b\x32\x13.xla.HloModuleProto\x12\x35\n\x11\x62uffer_assignment\x18\x03 \x01(\x0b\x32\x1a.xla.BufferAssignmentProtoJ\x04\x08\x02\x10\x03R\x0chlo_ordering\"\x8e\x01\n\x0bHloSnapshot\x12\x1a\n\x03hlo\x18\x01 \x01(\x0b\x32\r.xla.HloProto\x12$\n\targuments\x18\x02 \x03(\x0b\x32\x11.xla.LiteralProto\x12!\n\x06result\x18\x03 \x01(\x0b\x32\x11.xla.LiteralProto\x12\x1a\n\x12\x65xecution_platform\x18\x04 \x01(\tB\x03\xf8\x01\x01\x62\x06proto3')
  ,
  dependencies=[tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2.DESCRIPTOR,])



_HLOINPUTOUTPUTALIASPROTO_KIND = _descriptor.EnumDescriptor(
  name='Kind',
  full_name='xla.HloInputOutputAliasProto.Kind',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNDEFINED_ALIAS', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='USER_ALIAS', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SYSTEM_ALIAS', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3006,
  serialized_end=3067,
)
_sym_db.RegisterEnumDescriptor(_HLOINPUTOUTPUTALIASPROTO_KIND)

_HEAPSIMULATORTRACE_EVENT_KIND = _descriptor.EnumDescriptor(
  name='Kind',
  full_name='xla.HeapSimulatorTrace.Event.Kind',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ALLOC', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FREE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SHARE_WITH', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4540,
  serialized_end=4583,
)
_sym_db.RegisterEnumDescriptor(_HEAPSIMULATORTRACE_EVENT_KIND)


_HLOINSTRUCTIONPROTO_SLICEDIMENSIONS = _descriptor.Descriptor(
  name='SliceDimensions',
  full_name='xla.HloInstructionProto.SliceDimensions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='xla.HloInstructionProto.SliceDimensions.start', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='xla.HloInstructionProto.SliceDimensions.limit', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stride', full_name='xla.HloInstructionProto.SliceDimensions.stride', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2072,
  serialized_end=2135,
)

_HLOINSTRUCTIONPROTO = _descriptor.Descriptor(
  name='HloInstructionProto',
  full_name='xla.HloInstructionProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='xla.HloInstructionProto.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='opcode', full_name='xla.HloInstructionProto.opcode', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shape', full_name='xla.HloInstructionProto.shape', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='xla.HloInstructionProto.metadata', index=3,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='literal', full_name='xla.HloInstructionProto.literal', index=4,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parameter_number', full_name='xla.HloInstructionProto.parameter_number', index=5,
      number=9, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fusion_kind', full_name='xla.HloInstructionProto.fusion_kind', index=6,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tuple_index', full_name='xla.HloInstructionProto.tuple_index', index=7,
      number=13, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dimensions', full_name='xla.HloInstructionProto.dimensions', index=8,
      number=14, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='window', full_name='xla.HloInstructionProto.window', index=9,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='convolution_dimension_numbers', full_name='xla.HloInstructionProto.convolution_dimension_numbers', index=10,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='feature_group_count', full_name='xla.HloInstructionProto.feature_group_count', index=11,
      number=50, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='batch_group_count', full_name='xla.HloInstructionProto.batch_group_count', index=12,
      number=58, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slice_dimensions', full_name='xla.HloInstructionProto.slice_dimensions', index=13,
      number=17, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exponent_bits', full_name='xla.HloInstructionProto.exponent_bits', index=14,
      number=18, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mantissa_bits', full_name='xla.HloInstructionProto.mantissa_bits', index=15,
      number=19, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dynamic_slice_sizes', full_name='xla.HloInstructionProto.dynamic_slice_sizes', index=16,
      number=20, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='padding_config', full_name='xla.HloInstructionProto.padding_config', index=17,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outfeed_config', full_name='xla.HloInstructionProto.outfeed_config', index=18,
      number=22, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='distribution', full_name='xla.HloInstructionProto.distribution', index=19,
      number=23, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='epsilon', full_name='xla.HloInstructionProto.epsilon', index=20,
      number=24, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='feature_index', full_name='xla.HloInstructionProto.feature_index', index=21,
      number=25, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='channel_id', full_name='xla.HloInstructionProto.channel_id', index=22,
      number=26, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='infeed_config', full_name='xla.HloInstructionProto.infeed_config', index=23,
      number=27, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_call_target', full_name='xla.HloInstructionProto.custom_call_target', index=24,
      number=28, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outfeed_shape', full_name='xla.HloInstructionProto.outfeed_shape', index=25,
      number=29, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dot_dimension_numbers', full_name='xla.HloInstructionProto.dot_dimension_numbers', index=26,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fft_type', full_name='xla.HloInstructionProto.fft_type', index=27,
      number=31, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fft_length', full_name='xla.HloInstructionProto.fft_length', index=28,
      number=32, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='comparison_direction', full_name='xla.HloInstructionProto.comparison_direction', index=29,
      number=63, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gather_dimension_numbers', full_name='xla.HloInstructionProto.gather_dimension_numbers', index=30,
      number=33, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gather_slice_sizes', full_name='xla.HloInstructionProto.gather_slice_sizes', index=31,
      number=34, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='channel_name', full_name='xla.HloInstructionProto.channel_name', index=32,
      number=41, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cost_estimate_ns', full_name='xla.HloInstructionProto.cost_estimate_ns', index=33,
      number=42, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='xla.HloInstructionProto.id', index=34,
      number=35, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operand_ids', full_name='xla.HloInstructionProto.operand_ids', index=35,
      number=36, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='control_predecessor_ids', full_name='xla.HloInstructionProto.control_predecessor_ids', index=36,
      number=37, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='called_computation_ids', full_name='xla.HloInstructionProto.called_computation_ids', index=37,
      number=38, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sharding', full_name='xla.HloInstructionProto.sharding', index=38,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='backend_config', full_name='xla.HloInstructionProto.backend_config', index=39,
      number=43, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='replica_groups', full_name='xla.HloInstructionProto.replica_groups', index=40,
      number=49, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='all_reduce_id', full_name='xla.HloInstructionProto.all_reduce_id', index=41,
      number=45, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_host_transfer', full_name='xla.HloInstructionProto.is_host_transfer', index=42,
      number=47, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_stable', full_name='xla.HloInstructionProto.is_stable', index=43,
      number=60, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scatter_dimension_numbers', full_name='xla.HloInstructionProto.scatter_dimension_numbers', index=44,
      number=48, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='precision_config', full_name='xla.HloInstructionProto.precision_config', index=45,
      number=51, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source_target_pairs', full_name='xla.HloInstructionProto.source_target_pairs', index=46,
      number=52, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='domain_entry_sharding', full_name='xla.HloInstructionProto.domain_entry_sharding', index=47,
      number=54, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='domain_exit_sharding', full_name='xla.HloInstructionProto.domain_exit_sharding', index=48,
      number=55, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='constrain_layout', full_name='xla.HloInstructionProto.constrain_layout', index=49,
      number=56, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operand_shapes_with_layout', full_name='xla.HloInstructionProto.operand_shapes_with_layout', index=50,
      number=57, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='triangular_solve_options', full_name='xla.HloInstructionProto.triangular_solve_options', index=51,
      number=59, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cholesky_options', full_name='xla.HloInstructionProto.cholesky_options', index=52,
      number=62, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parameter_replication', full_name='xla.HloInstructionProto.parameter_replication', index=53,
      number=61, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outer_dimension_partitions', full_name='xla.HloInstructionProto.outer_dimension_partitions', index=54,
      number=64, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_call_has_side_effect', full_name='xla.HloInstructionProto.custom_call_has_side_effect', index=55,
      number=65, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='delta', full_name='xla.HloInstructionProto.delta', index=56,
      number=66, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='indices_are_sorted', full_name='xla.HloInstructionProto.indices_are_sorted', index=57,
      number=67, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_HLOINSTRUCTIONPROTO_SLICEDIMENSIONS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=91,
  serialized_end=2358,
)


_HLOCOMPUTATIONPROTO = _descriptor.Descriptor(
  name='HloComputationProto',
  full_name='xla.HloComputationProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='xla.HloComputationProto.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instructions', full_name='xla.HloComputationProto.instructions', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='program_shape', full_name='xla.HloComputationProto.program_shape', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='xla.HloComputationProto.id', index=3,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='root_id', full_name='xla.HloComputationProto.root_id', index=4,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2361,
  serialized_end=2537,
)


_HLOSCHEDULEPROTO_INSTRUCTIONSEQUENCE = _descriptor.Descriptor(
  name='InstructionSequence',
  full_name='xla.HloScheduleProto.InstructionSequence',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instruction_ids', full_name='xla.HloScheduleProto.InstructionSequence.instruction_ids', index=0,
      number=1, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2617,
  serialized_end=2663,
)

_HLOSCHEDULEPROTO_SEQUENCESENTRY = _descriptor.Descriptor(
  name='SequencesEntry',
  full_name='xla.HloScheduleProto.SequencesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='xla.HloScheduleProto.SequencesEntry.key', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='xla.HloScheduleProto.SequencesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2665,
  serialized_end=2756,
)

_HLOSCHEDULEPROTO = _descriptor.Descriptor(
  name='HloScheduleProto',
  full_name='xla.HloScheduleProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sequences', full_name='xla.HloScheduleProto.sequences', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_HLOSCHEDULEPROTO_INSTRUCTIONSEQUENCE, _HLOSCHEDULEPROTO_SEQUENCESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2540,
  serialized_end=2756,
)


_HLOINPUTOUTPUTALIASPROTO_ALIASENTRYPROTO = _descriptor.Descriptor(
  name='AliasEntryProto',
  full_name='xla.HloInputOutputAliasProto.AliasEntryProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='output_shape_index', full_name='xla.HloInputOutputAliasProto.AliasEntryProto.output_shape_index', index=0,
      number=1, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parameter_number', full_name='xla.HloInputOutputAliasProto.AliasEntryProto.parameter_number', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parameter_shape_index', full_name='xla.HloInputOutputAliasProto.AliasEntryProto.parameter_shape_index', index=2,
      number=3, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='kind', full_name='xla.HloInputOutputAliasProto.AliasEntryProto.kind', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2852,
  serialized_end=3004,
)

_HLOINPUTOUTPUTALIASPROTO = _descriptor.Descriptor(
  name='HloInputOutputAliasProto',
  full_name='xla.HloInputOutputAliasProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entries', full_name='xla.HloInputOutputAliasProto.entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_HLOINPUTOUTPUTALIASPROTO_ALIASENTRYPROTO, ],
  enum_types=[
    _HLOINPUTOUTPUTALIASPROTO_KIND,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2759,
  serialized_end=3067,
)


_DYNAMICPARAMETERBINDINGPROTO_BINDING = _descriptor.Descriptor(
  name='Binding',
  full_name='xla.DynamicParameterBindingProto.Binding',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dynamic_param_num', full_name='xla.DynamicParameterBindingProto.Binding.dynamic_param_num', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dynamic_param_index', full_name='xla.DynamicParameterBindingProto.Binding.dynamic_param_index', index=1,
      number=2, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='target_param_num', full_name='xla.DynamicParameterBindingProto.Binding.target_param_num', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='target_param_index', full_name='xla.DynamicParameterBindingProto.Binding.target_param_index', index=3,
      number=4, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='target_param_dim_num', full_name='xla.DynamicParameterBindingProto.Binding.target_param_dim_num', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3163,
  serialized_end=3312,
)

_DYNAMICPARAMETERBINDINGPROTO = _descriptor.Descriptor(
  name='DynamicParameterBindingProto',
  full_name='xla.DynamicParameterBindingProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entries', full_name='xla.DynamicParameterBindingProto.entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_DYNAMICPARAMETERBINDINGPROTO_BINDING, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3070,
  serialized_end=3312,
)


_HLOMODULEPROTO = _descriptor.Descriptor(
  name='HloModuleProto',
  full_name='xla.HloModuleProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='xla.HloModuleProto.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='entry_computation_name', full_name='xla.HloModuleProto.entry_computation_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='entry_computation_id', full_name='xla.HloModuleProto.entry_computation_id', index=2,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='computations', full_name='xla.HloModuleProto.computations', index=3,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='host_program_shape', full_name='xla.HloModuleProto.host_program_shape', index=4,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='xla.HloModuleProto.id', index=5,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='schedule', full_name='xla.HloModuleProto.schedule', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='input_output_alias', full_name='xla.HloModuleProto.input_output_alias', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dynamic_parameter_binding', full_name='xla.HloModuleProto.dynamic_parameter_binding', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3315,
  serialized_end=3689,
)


_LOGICALBUFFERPROTO_LOCATION = _descriptor.Descriptor(
  name='Location',
  full_name='xla.LogicalBufferProto.Location',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='computation_name', full_name='xla.LogicalBufferProto.Location.computation_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instruction_name', full_name='xla.LogicalBufferProto.Location.instruction_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shape_index', full_name='xla.LogicalBufferProto.Location.shape_index', index=2,
      number=3, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3809,
  serialized_end=3892,
)

_LOGICALBUFFERPROTO = _descriptor.Descriptor(
  name='LogicalBufferProto',
  full_name='xla.LogicalBufferProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='xla.LogicalBufferProto.id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size', full_name='xla.LogicalBufferProto.size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='defined_at', full_name='xla.LogicalBufferProto.defined_at', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='color', full_name='xla.LogicalBufferProto.color', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_LOGICALBUFFERPROTO_LOCATION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3692,
  serialized_end=3892,
)


_BUFFERALLOCATIONPROTO_ASSIGNED = _descriptor.Descriptor(
  name='Assigned',
  full_name='xla.BufferAllocationProto.Assigned',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='logical_buffer_id', full_name='xla.BufferAllocationProto.Assigned.logical_buffer_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='offset', full_name='xla.BufferAllocationProto.Assigned.offset', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size', full_name='xla.BufferAllocationProto.Assigned.size', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4204,
  serialized_end=4271,
)

_BUFFERALLOCATIONPROTO = _descriptor.Descriptor(
  name='BufferAllocationProto',
  full_name='xla.BufferAllocationProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='xla.BufferAllocationProto.index', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size', full_name='xla.BufferAllocationProto.size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_thread_local', full_name='xla.BufferAllocationProto.is_thread_local', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_tuple', full_name='xla.BufferAllocationProto.is_tuple', index=3,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_entry_computation_parameter', full_name='xla.BufferAllocationProto.is_entry_computation_parameter', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_constant', full_name='xla.BufferAllocationProto.is_constant', index=5,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parameter_number', full_name='xla.BufferAllocationProto.parameter_number', index=6,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parameter_shape_index', full_name='xla.BufferAllocationProto.parameter_shape_index', index=7,
      number=10, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='maybe_live_out', full_name='xla.BufferAllocationProto.maybe_live_out', index=8,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='color', full_name='xla.BufferAllocationProto.color', index=9,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='assigned', full_name='xla.BufferAllocationProto.assigned', index=10,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_BUFFERALLOCATIONPROTO_ASSIGNED, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3895,
  serialized_end=4271,
)


_HEAPSIMULATORTRACE_EVENT = _descriptor.Descriptor(
  name='Event',
  full_name='xla.HeapSimulatorTrace.Event',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='kind', full_name='xla.HeapSimulatorTrace.Event.kind', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='buffer_id', full_name='xla.HeapSimulatorTrace.Event.buffer_id', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='computation_name', full_name='xla.HeapSimulatorTrace.Event.computation_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instruction_name', full_name='xla.HeapSimulatorTrace.Event.instruction_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='share_with_canonical_id', full_name='xla.HeapSimulatorTrace.Event.share_with_canonical_id', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _HEAPSIMULATORTRACE_EVENT_KIND,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4377,
  serialized_end=4583,
)

_HEAPSIMULATORTRACE = _descriptor.Descriptor(
  name='HeapSimulatorTrace',
  full_name='xla.HeapSimulatorTrace',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='events', full_name='xla.HeapSimulatorTrace.events', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='whole_module_simulation', full_name='xla.HeapSimulatorTrace.whole_module_simulation', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_HEAPSIMULATORTRACE_EVENT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4274,
  serialized_end=4583,
)


_HLOMODULEGROUPPROTO = _descriptor.Descriptor(
  name='HloModuleGroupProto',
  full_name='xla.HloModuleGroupProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='xla.HloModuleGroupProto.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hlo_modules', full_name='xla.HloModuleGroupProto.hlo_modules', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4585,
  serialized_end=4662,
)


_BUFFERASSIGNMENTPROTO_BUFFERALIAS = _descriptor.Descriptor(
  name='BufferAlias',
  full_name='xla.BufferAssignmentProto.BufferAlias',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='source_buffer_id', full_name='xla.BufferAssignmentProto.BufferAlias.source_buffer_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='location', full_name='xla.BufferAssignmentProto.BufferAlias.location', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4916,
  serialized_end=5007,
)

_BUFFERASSIGNMENTPROTO = _descriptor.Descriptor(
  name='BufferAssignmentProto',
  full_name='xla.BufferAssignmentProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='logical_buffers', full_name='xla.BufferAssignmentProto.logical_buffers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='buffer_aliases', full_name='xla.BufferAssignmentProto.buffer_aliases', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='buffer_allocations', full_name='xla.BufferAssignmentProto.buffer_allocations', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='heap_simulator_traces', full_name='xla.BufferAssignmentProto.heap_simulator_traces', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_BUFFERASSIGNMENTPROTO_BUFFERALIAS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4665,
  serialized_end=5007,
)


_HLOPROTO = _descriptor.Descriptor(
  name='HloProto',
  full_name='xla.HloProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hlo_module', full_name='xla.HloProto.hlo_module', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='buffer_assignment', full_name='xla.HloProto.buffer_assignment', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5009,
  serialized_end=5135,
)


_HLOSNAPSHOT = _descriptor.Descriptor(
  name='HloSnapshot',
  full_name='xla.HloSnapshot',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hlo', full_name='xla.HloSnapshot.hlo', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='arguments', full_name='xla.HloSnapshot.arguments', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='result', full_name='xla.HloSnapshot.result', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='execution_platform', full_name='xla.HloSnapshot.execution_platform', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5138,
  serialized_end=5280,
)

_HLOINSTRUCTIONPROTO_SLICEDIMENSIONS.containing_type = _HLOINSTRUCTIONPROTO
_HLOINSTRUCTIONPROTO.fields_by_name['shape'].message_type = tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2._SHAPEPROTO
_HLOINSTRUCTIONPROTO.fields_by_name['metadata'].message_type = tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2._OPMETADATA
_HLOINSTRUCTIONPROTO.fields_by_name['literal'].message_type = tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2._LITERALPROTO
_HLOINSTRUCTIONPROTO.fields_by_name['window'].message_type = tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2._WINDOW
_HLOINSTRUCTIONPROTO.fields_by_name['convolution_dimension_numbers'].message_type = tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2._CONVOLUTIONDIMENSIONNUMBERS
_HLOINSTRUCTIONPROTO.fields_by_name['slice_dimensions'].message_type = _HLOINSTRUCTIONPROTO_SLICEDIMENSIONS
_HLOINSTRUCTIONPROTO.fields_by_name['padding_config'].message_type = tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2._PADDINGCONFIG
_HLOINSTRUCTIONPROTO.fields_by_name['distribution'].enum_type = tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2._RANDOMDISTRIBUTION
_HLOINSTRUCTIONPROTO.fields_by_name['outfeed_shape'].message_type = tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2._SHAPEPROTO
_HLOINSTRUCTIONPROTO.fields_by_name['dot_dimension_numbers'].message_type = tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2._DOTDIMENSIONNUMBERS
_HLOINSTRUCTIONPROTO.fields_by_name['fft_type'].enum_type = tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2._FFTTYPE
_HLOINSTRUCTIONPROTO.fields_by_name['gather_dimension_numbers'].message_type = tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2._GATHERDIMENSIONNUMBERS
_HLOINSTRUCTIONPROTO.fields_by_name['sharding'].message_type = tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2._OPSHARDING
_HLOINSTRUCTIONPROTO.fields_by_name['replica_groups'].message_type = tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2._REPLICAGROUP
_HLOINSTRUCTIONPROTO.fields_by_name['scatter_dimension_numbers'].message_type = tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2._SCATTERDIMENSIONNUMBERS
_HLOINSTRUCTIONPROTO.fields_by_name['precision_config'].message_type = tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2._PRECISIONCONFIG
_HLOINSTRUCTIONPROTO.fields_by_name['source_target_pairs'].message_type = tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2._SOURCETARGET
_HLOINSTRUCTIONPROTO.fields_by_name['domain_entry_sharding'].message_type = tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2._OPSHARDING
_HLOINSTRUCTIONPROTO.fields_by_name['domain_exit_sharding'].message_type = tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2._OPSHARDING
_HLOINSTRUCTIONPROTO.fields_by_name['operand_shapes_with_layout'].message_type = tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2._SHAPEPROTO
_HLOINSTRUCTIONPROTO.fields_by_name['triangular_solve_options'].message_type = tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2._TRIANGULARSOLVEOPTIONS
_HLOINSTRUCTIONPROTO.fields_by_name['cholesky_options'].message_type = tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2._CHOLESKYOPTIONS
_HLOINSTRUCTIONPROTO.fields_by_name['parameter_replication'].message_type = tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2._PARAMETERREPLICATION
_HLOCOMPUTATIONPROTO.fields_by_name['instructions'].message_type = _HLOINSTRUCTIONPROTO
_HLOCOMPUTATIONPROTO.fields_by_name['program_shape'].message_type = tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2._PROGRAMSHAPEPROTO
_HLOSCHEDULEPROTO_INSTRUCTIONSEQUENCE.containing_type = _HLOSCHEDULEPROTO
_HLOSCHEDULEPROTO_SEQUENCESENTRY.fields_by_name['value'].message_type = _HLOSCHEDULEPROTO_INSTRUCTIONSEQUENCE
_HLOSCHEDULEPROTO_SEQUENCESENTRY.containing_type = _HLOSCHEDULEPROTO
_HLOSCHEDULEPROTO.fields_by_name['sequences'].message_type = _HLOSCHEDULEPROTO_SEQUENCESENTRY
_HLOINPUTOUTPUTALIASPROTO_ALIASENTRYPROTO.fields_by_name['kind'].enum_type = _HLOINPUTOUTPUTALIASPROTO_KIND
_HLOINPUTOUTPUTALIASPROTO_ALIASENTRYPROTO.containing_type = _HLOINPUTOUTPUTALIASPROTO
_HLOINPUTOUTPUTALIASPROTO.fields_by_name['entries'].message_type = _HLOINPUTOUTPUTALIASPROTO_ALIASENTRYPROTO
_HLOINPUTOUTPUTALIASPROTO_KIND.containing_type = _HLOINPUTOUTPUTALIASPROTO
_DYNAMICPARAMETERBINDINGPROTO_BINDING.containing_type = _DYNAMICPARAMETERBINDINGPROTO
_DYNAMICPARAMETERBINDINGPROTO.fields_by_name['entries'].message_type = _DYNAMICPARAMETERBINDINGPROTO_BINDING
_HLOMODULEPROTO.fields_by_name['computations'].message_type = _HLOCOMPUTATIONPROTO
_HLOMODULEPROTO.fields_by_name['host_program_shape'].message_type = tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2._PROGRAMSHAPEPROTO
_HLOMODULEPROTO.fields_by_name['schedule'].message_type = _HLOSCHEDULEPROTO
_HLOMODULEPROTO.fields_by_name['input_output_alias'].message_type = _HLOINPUTOUTPUTALIASPROTO
_HLOMODULEPROTO.fields_by_name['dynamic_parameter_binding'].message_type = _DYNAMICPARAMETERBINDINGPROTO
_LOGICALBUFFERPROTO_LOCATION.containing_type = _LOGICALBUFFERPROTO
_LOGICALBUFFERPROTO.fields_by_name['defined_at'].message_type = _LOGICALBUFFERPROTO_LOCATION
_BUFFERALLOCATIONPROTO_ASSIGNED.containing_type = _BUFFERALLOCATIONPROTO
_BUFFERALLOCATIONPROTO.fields_by_name['assigned'].message_type = _BUFFERALLOCATIONPROTO_ASSIGNED
_HEAPSIMULATORTRACE_EVENT.fields_by_name['kind'].enum_type = _HEAPSIMULATORTRACE_EVENT_KIND
_HEAPSIMULATORTRACE_EVENT.containing_type = _HEAPSIMULATORTRACE
_HEAPSIMULATORTRACE_EVENT_KIND.containing_type = _HEAPSIMULATORTRACE_EVENT
_HEAPSIMULATORTRACE.fields_by_name['events'].message_type = _HEAPSIMULATORTRACE_EVENT
_HLOMODULEGROUPPROTO.fields_by_name['hlo_modules'].message_type = _HLOMODULEPROTO
_BUFFERASSIGNMENTPROTO_BUFFERALIAS.fields_by_name['location'].message_type = _LOGICALBUFFERPROTO_LOCATION
_BUFFERASSIGNMENTPROTO_BUFFERALIAS.containing_type = _BUFFERASSIGNMENTPROTO
_BUFFERASSIGNMENTPROTO.fields_by_name['logical_buffers'].message_type = _LOGICALBUFFERPROTO
_BUFFERASSIGNMENTPROTO.fields_by_name['buffer_aliases'].message_type = _BUFFERASSIGNMENTPROTO_BUFFERALIAS
_BUFFERASSIGNMENTPROTO.fields_by_name['buffer_allocations'].message_type = _BUFFERALLOCATIONPROTO
_BUFFERASSIGNMENTPROTO.fields_by_name['heap_simulator_traces'].message_type = _HEAPSIMULATORTRACE
_HLOPROTO.fields_by_name['hlo_module'].message_type = _HLOMODULEPROTO
_HLOPROTO.fields_by_name['buffer_assignment'].message_type = _BUFFERASSIGNMENTPROTO
_HLOSNAPSHOT.fields_by_name['hlo'].message_type = _HLOPROTO
_HLOSNAPSHOT.fields_by_name['arguments'].message_type = tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2._LITERALPROTO
_HLOSNAPSHOT.fields_by_name['result'].message_type = tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2._LITERALPROTO
DESCRIPTOR.message_types_by_name['HloInstructionProto'] = _HLOINSTRUCTIONPROTO
DESCRIPTOR.message_types_by_name['HloComputationProto'] = _HLOCOMPUTATIONPROTO
DESCRIPTOR.message_types_by_name['HloScheduleProto'] = _HLOSCHEDULEPROTO
DESCRIPTOR.message_types_by_name['HloInputOutputAliasProto'] = _HLOINPUTOUTPUTALIASPROTO
DESCRIPTOR.message_types_by_name['DynamicParameterBindingProto'] = _DYNAMICPARAMETERBINDINGPROTO
DESCRIPTOR.message_types_by_name['HloModuleProto'] = _HLOMODULEPROTO
DESCRIPTOR.message_types_by_name['LogicalBufferProto'] = _LOGICALBUFFERPROTO
DESCRIPTOR.message_types_by_name['BufferAllocationProto'] = _BUFFERALLOCATIONPROTO
DESCRIPTOR.message_types_by_name['HeapSimulatorTrace'] = _HEAPSIMULATORTRACE
DESCRIPTOR.message_types_by_name['HloModuleGroupProto'] = _HLOMODULEGROUPPROTO
DESCRIPTOR.message_types_by_name['BufferAssignmentProto'] = _BUFFERASSIGNMENTPROTO
DESCRIPTOR.message_types_by_name['HloProto'] = _HLOPROTO
DESCRIPTOR.message_types_by_name['HloSnapshot'] = _HLOSNAPSHOT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

HloInstructionProto = _reflection.GeneratedProtocolMessageType('HloInstructionProto', (_message.Message,), {

  'SliceDimensions' : _reflection.GeneratedProtocolMessageType('SliceDimensions', (_message.Message,), {
    'DESCRIPTOR' : _HLOINSTRUCTIONPROTO_SLICEDIMENSIONS,
    '__module__' : 'tensorflow.compiler.xla.service.hlo_pb2'
    # @@protoc_insertion_point(class_scope:xla.HloInstructionProto.SliceDimensions)
    })
  ,
  'DESCRIPTOR' : _HLOINSTRUCTIONPROTO,
  '__module__' : 'tensorflow.compiler.xla.service.hlo_pb2'
  # @@protoc_insertion_point(class_scope:xla.HloInstructionProto)
  })
_sym_db.RegisterMessage(HloInstructionProto)
_sym_db.RegisterMessage(HloInstructionProto.SliceDimensions)

HloComputationProto = _reflection.GeneratedProtocolMessageType('HloComputationProto', (_message.Message,), {
  'DESCRIPTOR' : _HLOCOMPUTATIONPROTO,
  '__module__' : 'tensorflow.compiler.xla.service.hlo_pb2'
  # @@protoc_insertion_point(class_scope:xla.HloComputationProto)
  })
_sym_db.RegisterMessage(HloComputationProto)

HloScheduleProto = _reflection.GeneratedProtocolMessageType('HloScheduleProto', (_message.Message,), {

  'InstructionSequence' : _reflection.GeneratedProtocolMessageType('InstructionSequence', (_message.Message,), {
    'DESCRIPTOR' : _HLOSCHEDULEPROTO_INSTRUCTIONSEQUENCE,
    '__module__' : 'tensorflow.compiler.xla.service.hlo_pb2'
    # @@protoc_insertion_point(class_scope:xla.HloScheduleProto.InstructionSequence)
    })
  ,

  'SequencesEntry' : _reflection.GeneratedProtocolMessageType('SequencesEntry', (_message.Message,), {
    'DESCRIPTOR' : _HLOSCHEDULEPROTO_SEQUENCESENTRY,
    '__module__' : 'tensorflow.compiler.xla.service.hlo_pb2'
    # @@protoc_insertion_point(class_scope:xla.HloScheduleProto.SequencesEntry)
    })
  ,
  'DESCRIPTOR' : _HLOSCHEDULEPROTO,
  '__module__' : 'tensorflow.compiler.xla.service.hlo_pb2'
  # @@protoc_insertion_point(class_scope:xla.HloScheduleProto)
  })
_sym_db.RegisterMessage(HloScheduleProto)
_sym_db.RegisterMessage(HloScheduleProto.InstructionSequence)
_sym_db.RegisterMessage(HloScheduleProto.SequencesEntry)

HloInputOutputAliasProto = _reflection.GeneratedProtocolMessageType('HloInputOutputAliasProto', (_message.Message,), {

  'AliasEntryProto' : _reflection.GeneratedProtocolMessageType('AliasEntryProto', (_message.Message,), {
    'DESCRIPTOR' : _HLOINPUTOUTPUTALIASPROTO_ALIASENTRYPROTO,
    '__module__' : 'tensorflow.compiler.xla.service.hlo_pb2'
    # @@protoc_insertion_point(class_scope:xla.HloInputOutputAliasProto.AliasEntryProto)
    })
  ,
  'DESCRIPTOR' : _HLOINPUTOUTPUTALIASPROTO,
  '__module__' : 'tensorflow.compiler.xla.service.hlo_pb2'
  # @@protoc_insertion_point(class_scope:xla.HloInputOutputAliasProto)
  })
_sym_db.RegisterMessage(HloInputOutputAliasProto)
_sym_db.RegisterMessage(HloInputOutputAliasProto.AliasEntryProto)

DynamicParameterBindingProto = _reflection.GeneratedProtocolMessageType('DynamicParameterBindingProto', (_message.Message,), {

  'Binding' : _reflection.GeneratedProtocolMessageType('Binding', (_message.Message,), {
    'DESCRIPTOR' : _DYNAMICPARAMETERBINDINGPROTO_BINDING,
    '__module__' : 'tensorflow.compiler.xla.service.hlo_pb2'
    # @@protoc_insertion_point(class_scope:xla.DynamicParameterBindingProto.Binding)
    })
  ,
  'DESCRIPTOR' : _DYNAMICPARAMETERBINDINGPROTO,
  '__module__' : 'tensorflow.compiler.xla.service.hlo_pb2'
  # @@protoc_insertion_point(class_scope:xla.DynamicParameterBindingProto)
  })
_sym_db.RegisterMessage(DynamicParameterBindingProto)
_sym_db.RegisterMessage(DynamicParameterBindingProto.Binding)

HloModuleProto = _reflection.GeneratedProtocolMessageType('HloModuleProto', (_message.Message,), {
  'DESCRIPTOR' : _HLOMODULEPROTO,
  '__module__' : 'tensorflow.compiler.xla.service.hlo_pb2'
  # @@protoc_insertion_point(class_scope:xla.HloModuleProto)
  })
_sym_db.RegisterMessage(HloModuleProto)

LogicalBufferProto = _reflection.GeneratedProtocolMessageType('LogicalBufferProto', (_message.Message,), {

  'Location' : _reflection.GeneratedProtocolMessageType('Location', (_message.Message,), {
    'DESCRIPTOR' : _LOGICALBUFFERPROTO_LOCATION,
    '__module__' : 'tensorflow.compiler.xla.service.hlo_pb2'
    # @@protoc_insertion_point(class_scope:xla.LogicalBufferProto.Location)
    })
  ,
  'DESCRIPTOR' : _LOGICALBUFFERPROTO,
  '__module__' : 'tensorflow.compiler.xla.service.hlo_pb2'
  # @@protoc_insertion_point(class_scope:xla.LogicalBufferProto)
  })
_sym_db.RegisterMessage(LogicalBufferProto)
_sym_db.RegisterMessage(LogicalBufferProto.Location)

BufferAllocationProto = _reflection.GeneratedProtocolMessageType('BufferAllocationProto', (_message.Message,), {

  'Assigned' : _reflection.GeneratedProtocolMessageType('Assigned', (_message.Message,), {
    'DESCRIPTOR' : _BUFFERALLOCATIONPROTO_ASSIGNED,
    '__module__' : 'tensorflow.compiler.xla.service.hlo_pb2'
    # @@protoc_insertion_point(class_scope:xla.BufferAllocationProto.Assigned)
    })
  ,
  'DESCRIPTOR' : _BUFFERALLOCATIONPROTO,
  '__module__' : 'tensorflow.compiler.xla.service.hlo_pb2'
  # @@protoc_insertion_point(class_scope:xla.BufferAllocationProto)
  })
_sym_db.RegisterMessage(BufferAllocationProto)
_sym_db.RegisterMessage(BufferAllocationProto.Assigned)

HeapSimulatorTrace = _reflection.GeneratedProtocolMessageType('HeapSimulatorTrace', (_message.Message,), {

  'Event' : _reflection.GeneratedProtocolMessageType('Event', (_message.Message,), {
    'DESCRIPTOR' : _HEAPSIMULATORTRACE_EVENT,
    '__module__' : 'tensorflow.compiler.xla.service.hlo_pb2'
    # @@protoc_insertion_point(class_scope:xla.HeapSimulatorTrace.Event)
    })
  ,
  'DESCRIPTOR' : _HEAPSIMULATORTRACE,
  '__module__' : 'tensorflow.compiler.xla.service.hlo_pb2'
  # @@protoc_insertion_point(class_scope:xla.HeapSimulatorTrace)
  })
_sym_db.RegisterMessage(HeapSimulatorTrace)
_sym_db.RegisterMessage(HeapSimulatorTrace.Event)

HloModuleGroupProto = _reflection.GeneratedProtocolMessageType('HloModuleGroupProto', (_message.Message,), {
  'DESCRIPTOR' : _HLOMODULEGROUPPROTO,
  '__module__' : 'tensorflow.compiler.xla.service.hlo_pb2'
  # @@protoc_insertion_point(class_scope:xla.HloModuleGroupProto)
  })
_sym_db.RegisterMessage(HloModuleGroupProto)

BufferAssignmentProto = _reflection.GeneratedProtocolMessageType('BufferAssignmentProto', (_message.Message,), {

  'BufferAlias' : _reflection.GeneratedProtocolMessageType('BufferAlias', (_message.Message,), {
    'DESCRIPTOR' : _BUFFERASSIGNMENTPROTO_BUFFERALIAS,
    '__module__' : 'tensorflow.compiler.xla.service.hlo_pb2'
    # @@protoc_insertion_point(class_scope:xla.BufferAssignmentProto.BufferAlias)
    })
  ,
  'DESCRIPTOR' : _BUFFERASSIGNMENTPROTO,
  '__module__' : 'tensorflow.compiler.xla.service.hlo_pb2'
  # @@protoc_insertion_point(class_scope:xla.BufferAssignmentProto)
  })
_sym_db.RegisterMessage(BufferAssignmentProto)
_sym_db.RegisterMessage(BufferAssignmentProto.BufferAlias)

HloProto = _reflection.GeneratedProtocolMessageType('HloProto', (_message.Message,), {
  'DESCRIPTOR' : _HLOPROTO,
  '__module__' : 'tensorflow.compiler.xla.service.hlo_pb2'
  # @@protoc_insertion_point(class_scope:xla.HloProto)
  })
_sym_db.RegisterMessage(HloProto)

HloSnapshot = _reflection.GeneratedProtocolMessageType('HloSnapshot', (_message.Message,), {
  'DESCRIPTOR' : _HLOSNAPSHOT,
  '__module__' : 'tensorflow.compiler.xla.service.hlo_pb2'
  # @@protoc_insertion_point(class_scope:xla.HloSnapshot)
  })
_sym_db.RegisterMessage(HloSnapshot)


DESCRIPTOR._options = None
_HLOINSTRUCTIONPROTO.fields_by_name['all_reduce_id']._options = None
_HLOSCHEDULEPROTO_SEQUENCESENTRY._options = None
# @@protoc_insertion_point(module_scope)
